<!--
This file is part of XO, an XML/XSL outliner.
XO comes with no warranty and no restrictions.  It is hereby placed in
the Public Domain by me, Steve Tinney (stinney@sas.upenn.edu), sole
author of all code in this archive.
-->
<xsl:stylesheet version="1.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:strip-space elements="*"/>
<xsl:output method="html" indent="yes"/>

<xsl:template match="/">
  <xsl:comment>Outline generated by XO.</xsl:comment>
  <html>
    <head><link rel="stylesheet" type="text/css" href="xo.css"/>
      <title><xsl:value-of select="/outline/h"/></title>
    </head>
    <body><xsl:apply-templates/></body>
  </html>
</xsl:template>

<xsl:template match="outline">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="pt">
  <xsl:if test="count(preceding-sibling::pt) = 0
		or not(preceding-sibling::*[1][name()='pt'])">
    <xsl:call-template name="make-list"/>
  </xsl:if>
</xsl:template>

<xsl:template match="it">
  <xsl:if test="count(preceding-sibling::it) = 0
		or not(preceding-sibling::*[1][name()='it'])">
    <xsl:call-template name="make-list">
      <xsl:with-param name="list-gi" select="'ul'"/>
    </xsl:call-template>
  </xsl:if>
</xsl:template>

<xsl:template match="outline/h">
  <h1><xsl:apply-templates/></h1>
</xsl:template>

<xsl:template match="h">
  <p class="h"><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="p">
  <p><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="a|i|b|em">
  <xsl:copy-of select="."/>
</xsl:template>

<xsl:template name="make-list">
  <xsl:param name="list-gi" select="'ol'"/>
  <xsl:param name="item-gi" select="name()"/>
  <xsl:element name="{$list-gi}">
    <xsl:variable name="offset" 
      select="count(preceding-sibling::*[not(name()=$item-gi)])"/>
    <xsl:variable name="top"
         select="1+count(following-sibling::*
                         [name()=$item-gi and 
                          count(preceding-sibling::*
                                [not(name()=$item-gi)])
                            = $offset])"/>
    <xsl:for-each 
      select=".|following-sibling::*
                [name()=$item-gi and position() &lt; $top]">
      <xsl:choose>
        <xsl:when test="name()=$item-gi">
          <li><xsl:apply-templates/></li>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates select="."/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
  </xsl:element>
</xsl:template>

</xsl:stylesheet>
